<?php

namespace Payroll\Attendance\Http\Controllers\Api;

use App\Http\Controllers\Api\PublicController as BaseController;
use Payroll\Attendance\Interfaces\AttendanceRepositoryInterface;
use Payroll\Attendance\Repositories\Presenter\AttendanceItemTransformer;

/**
 * Pubic API controller class.
 */
class AttendancePublicController extends BaseController
{
    /**
     * Constructor.
     *
     * @param type \Payroll\Attendance\Interfaces\AttendanceRepositoryInterface $attendance
     *
     * @return type
     */
    public function __construct(AttendanceRepositoryInterface $attendance)
    {
        $this->repository = $attendance;
        parent::__construct();
    }

    /**
     * Show attendance's list.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function index()
    {
        $attendances = $this->repository
            ->setPresenter('\\Payroll\\Attendance\\Repositories\\Presenter\\AttendanceListPresenter')
            ->scopeQuery(function($query){
                return $query->orderBy('id','DESC');
            })->paginate();

        $attendances['code'] = 2000;
        return response()->json($attendances)
                ->setStatusCode(200, 'INDEX_SUCCESS');
    }

    /**
     * Show attendance.
     *
     * @param string $slug
     *
     * @return response
     */
    protected function show($slug)
    {
        $attendance = $this->repository
            ->scopeQuery(function($query) use ($slug) {
            return $query->orderBy('id','DESC')
                         ->where('slug', $slug);
        })->first(['*']);

        if (!is_null($attendance)) {
            $attendance         = $this->itemPresenter($module, new AttendanceItemTransformer);
            $attendance['code'] = 2001;
            return response()->json($attendance)
                ->setStatusCode(200, 'SHOW_SUCCESS');
        } else {
            return response()->json([])
                ->setStatusCode(400, 'SHOW_ERROR');
        }

    }
}
