<?php

namespace Payroll\Attendance\Workflow;

use Exception;
use Litepie\Workflow\Exceptions\WorkflowActionNotPerformedException;

use Payroll\Attendance\Models\Attendance;

class AttendanceAction
{
    /**
     * Perform the complete action.
     *
     * @param Attendance $attendance
     *
     * @return Attendance
     */
    public function complete(Attendance $attendance)
    {
        try {
            $attendance->status = 'complete';
            return $attendance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the verify action.
     *
     * @param Attendance $attendance
     *
     * @return Attendance
     */public function verify(Attendance $attendance)
    {
        try {
            $attendance->status = 'verify';
            return $attendance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the approve action.
     *
     * @param Attendance $attendance
     *
     * @return Attendance
     */public function approve(Attendance $attendance)
    {
        try {
            $attendance->status = 'approve';
            return $attendance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the publish action.
     *
     * @param Attendance $attendance
     *
     * @return Attendance
     */public function publish(Attendance $attendance)
    {
        try {
            $attendance->status = 'publish';
            return $attendance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the archive action.
     *
     * @param Attendance $attendance
     *
     * @return Attendance
     */
    public function archive(Attendance $attendance)
    {
        try {
            $attendance->status = 'archive';
            return $attendance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }

    /**
     * Perform the unpublish action.
     *
     * @param Attendance $attendance
     *
     * @return Attendance
     */
    public function unpublish(Attendance $attendance)
    {
        try {
            $attendance->status = 'unpublish';
            return $attendance->save();
        } catch (Exception $e) {
            throw new WorkflowActionNotPerformedException();
        }
    }
}
