<?php

namespace Payroll\Attendance\Workflow;

use Payroll\Attendance\Models\Attendance;
use Validator;

class AttendanceValidator
{

    /**
     * Determine if the given attendance is valid for complete status.
     *
     * @param Attendance $attendance
     *
     * @return bool / Validator
     */
    public function complete(Attendance $attendance)
    {
        return Validator::make($attendance->toArray(), [
            'title' => 'required|min:15',
        ]);
    }

    /**
     * Determine if the given attendance is valid for verify status.
     *
     * @param Attendance $attendance
     *
     * @return bool / Validator
     */
    public function verify(Attendance $attendance)
    {
        return Validator::make($attendance->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:complete',
        ]);
    }

    /**
     * Determine if the given attendance is valid for approve status.
     *
     * @param Attendance $attendance
     *
     * @return bool / Validator
     */
    public function approve(Attendance $attendance)
    {
        return Validator::make($attendance->toArray(), [
            'title'  => 'required|min:15',
            'status' => 'in:verify',
        ]);

    }

    /**
     * Determine if the given attendance is valid for publish status.
     *
     * @param Attendance $attendance
     *
     * @return bool / Validator
     */
    public function publish(Attendance $attendance)
    {
        return Validator::make($attendance->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,archive,unpublish',
        ]);

    }

    /**
     * Determine if the given attendance is valid for archive status.
     *
     * @param Attendance $attendance
     *
     * @return bool / Validator
     */
    public function archive(Attendance $attendance)
    {
        return Validator::make($attendance->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:approve,publish,unpublish',
        ]);

    }

    /**
     * Determine if the given attendance is valid for unpublish status.
     *
     * @param Attendance $attendance
     *
     * @return bool / Validator
     */
    public function unpublish(Attendance $attendance)
    {
        return Validator::make($attendance->toArray(), [
            'title'       => 'required|min:15',
            'description' => 'required|min:50',
            'status'      => 'in:publish',
        ]);

    }
}
